@@ -48,7 +48,7 @@
  *
  * @date 2008 (created)
  *
- * @section toc Table of Contents
+ * @section eina_toc Table of Contents
  *
  * @li @ref eina_main_intro
  * @li @ref eina_main_compiling
@@ -57,15 +57,15 @@
  *
  * @section eina_main_intro Introduction
  *
- * The Eina library is a library that implements an API for data types
+ * The Eina library is a library which implements an API for data types
  * in an efficient way. It also provides some useful tools like
- * opening shared libraries, errors management, type conversion,
- * time accounting and memory pool.
+ * opening shared libraries, error management, type conversion,
+ * time accounting and memory pools.
  *
  * This library is cross-platform and can be compiled and used on
- * Linux, BSD, Opensolaris and Windows (XP and CE).
+ * Linux, BSD, and Windows.
  *
- * The data types that are available are (see @ref Eina_Data_Types_Group):
+ * The data types available are (see @ref Eina_Data_Types_Group):
  * @li @ref Eina_Fp_Group standard floating point numbers.
  * @li @ref Eina_Inline_Array_Group standard array of inlined members.
  * @li @ref Eina_Array_Group standard array of @c void* data.
@@ -81,9 +81,8 @@
  * @li @ref Eina_Tiler_Group split, merge and navigates into 2D tiled regions.
  * @li @ref Eina_Trash_Group container of unused but allocated data.
  * @li @ref Eina_Value_Group container for generic value storage and access.
- * @li @ref Eina_Model_Group container for data with user defined hierarchy/structure.
  *
- * The tools that are available are (see @ref Eina_Tools_Group):
+ * The tools available are (see @ref Eina_Tools_Group):
  * @li @ref Eina_Benchmark_Group helper to write benchmarks.
  * @li @ref Eina_Convert_Group faster conversion from strings to integers, double, etc.
  * @li @ref Eina_Counter_Group measures number of calls and their time.
@@ -101,9 +100,9 @@
  *
  * @section eina_main_compiling How to compile
  *
- * Eina is a library your application links to. The procedure for this is
+ * Eina is a library to which your app can link. The procedure for this is
  * very simple. You simply have to compile your application with the
- * appropriate compiler flags that the @c pkg-config script outputs. For
+ * appropriate compiler flags as outputted by the @c pkg-config script. For
  * example:
  *
  * Compiling C or C++ files into object files:
@@ -122,8 +121,8 @@
  *
  * @section eina_main_next_steps Next Steps
  *
- * After you understood what Eina is and installed it in your system
- * you should proceed understanding the programming interface.
+ * After you've understood what Eina is and installed it,
+ * you can now learn more about the the programming interface.
  *
  * Recommended reading:
  *
@@ -138,12 +137,16 @@
  * More examples can be found at @ref eina_examples.
  *
  *
+ * @defgroup Eina_Core_Group Core
+ * @brief Initialization, shut down and core types.
+ * @ingroup Eina
+ *
  * @defgroup Eina_Data_Types_Group Data Types
  * @brief Eina provides an easy to use and optimized data types and structures.
  * @ingroup Eina
  *
  * @defgroup Eina_Content_Access_Group Content Access
- * @brief Eina provides an uniform way to access elements of a container,
+ * @brief Eina provides a uniform way to access elements of a container,
  *        either sequential or indexed.
  * @ingroup Eina_Data_Types_Group
  *
@@ -164,49 +167,45 @@
  *
  * The choice of which container to use in each situation is very important in
  * achieving good performance and readable code. The most common container types
- * to be used are:
+ * used are:
  * @li List
  * @li Inline list
  * @li Array
  * @li Inline array
  * @li Hash
  *
- * All types have virtues and vices. The following considerations are good
+ * All types have pros and cons. The following considerations are good
  * starting point in deciding which container to use:
- * @li Hashes are appropriate for datasets which will be searched often;
- * @li arrays are good when accessing members by position;
- * @li lists provide good versatility for adding elements in any position with
- * minimal overhead;
- * @li inline arrays use very little memory and don't cause fragmentation and
- * therefore are a good option in memory constrained systems;
- * @li inline lists are the appropriate type to use when the flexibility of a
- * list is required but the overhead of pointer indirection is not acceptable.
- * @warning These are general considerations, every situation is different,
- * don't follow these recommendations blindly.
+ * @li Hashes are appropriate for datasets which will be searched often.
+ * @li Arrays are good when accessing members by position;
+ * @li Lists provide good versatility for adding elements in any position with
+ * minimal overhead.
+ * @li Inline arrays use very little memory and don't cause fragmentation so
+ * are a good option in memory constrained systems.
+ * @li Inline lists are the best type to use when list flexibility is
+ * required but no pointer indirection overhead can be allowed.
+ * @warning These are general considerations. Every situation is different.
+ * Don't follow these recommendations blindly.
  *
  * @section eina_main_Creation Creating custom container types
  *
- * @note Before creating a custom container check if one of the existing ones
- * doesn't suit your needs. For example, while there is no stack type @ref
- * Eina_Array_Group is a very good substitute, similarly there is no queue type
+ * @note Before creating a custom container check if any of the existing ones
+ * suit your needs. For example, while there is no stack type @ref
+ * Eina_Array_Group is a very good substitute. Similarly there is no queue type
  * however an @ref Eina_List_Group works very well as a queue.
  *
- * If creating a custom container type consider allowing access to the data in
+ * If creating a custom container type, consider allowing access to the data in
  * your container through @ref Eina_Iterator_Group "Iterators" and @ref
  * Eina_Accessor_Group "Accessors". To do so your container should have an
- * iterator creation function and an accessor creation function, these functions
+ * iterator creation function and an accessor creation function. These functions
  * should return properly populated @ref _Eina_Iterator and @ref _Eina_Accessor.
  *
  * @defgroup Eina_Tools_Group Tools
+ * @ingroup Eina
  * @brief Eina tools aims to help application development, providing ways to
  *        make it safer, log errors, manage memory more efficiently and more.
- * @ingroup Eina
  */
 
-#ifdef _WIN32
-# include <Evil.h>
-#endif
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -215,8 +214,10 @@ extern "C" {
 #include <eina_types.h>
 #include <eina_alloca.h>
 #include <eina_main.h>
+#include <eina_fnmatch.h>
 #include <eina_fp.h>
 #include <eina_rectangle.h>
+#include <eina_range.h>
 #include <eina_clist.h>
 #include <eina_inlist.h>
 #include <eina_file.h>
@@ -241,9 +242,7 @@ extern "C" {
 #include <eina_benchmark.h>
 #include <eina_convert.h>
 #include <eina_cpu.h>
-#include <eina_sched.h>
 #include <eina_tiler.h>
-#include <eina_thread.h>
 #include <eina_hamster.h>
 #include <eina_matrixsparse.h>
 #include <eina_str.h>
@@ -254,6 +253,7 @@ extern "C" {
 #include <eina_quadtree.h>
 #include <eina_simple_xml_parser.h>
 #include <eina_lock.h>
+#include <eina_thread.h> /* after eina_lock.h since it will include pthread.h with proper flags */
 #include <eina_prefix.h>
 #include <eina_refcount.h>
 #include <eina_mmap.h>
@@ -269,9 +269,15 @@ extern "C" {
 #include <eina_util.h>
 #include <eina_quaternion.h>
 #include <eina_bezier.h>
+#include <eina_safepointer.h>
+#include <eina_slice.h>
+#include <eina_freeq.h>
+#include <eina_slstr.h>
+#include <eina_debug.h>
+#include <eina_promise.h>
+#include <eina_vpath.h>
+#include <eina_abstract_content.h>
 
-#undef EAPI
-#define EAPI
 
 #ifdef __cplusplus
 }
